@@ -1,7 +1,7 @@
 from os.path import exists
 import json
 
-class File:
+class FFile:
 	"""Gestionale dei file"""
 	nomeFile: str
 	"""Nome del file da leggere"""
