@@ -1,6 +1,6 @@
-from .File import *
+from FilesOp.File import FFile
 
 __author__ = """KingKaitoKid"""
 __email__ = 'djstrix@me.com'
-__version__ = '1.0.9'
+__version__ = '1.0.12'
 name = "FilesOp"
\ No newline at end of file
